/**************************************************
 *
 * This file contains an interrupt vector 
 * KamCho. (Cortex-M written in C)
 * The actual interrupt functions must be provided 
 * by the application developer.
 *
 * Copyright 2007 IAR Systems. All rights reserved.
 *
 * $Revision: 134 $
 *
 **************************************************/

#pragma language=extended
#pragma segment="CSTACK"

extern void __iar_program_start( void );

extern void NMI_Handler( void );
extern void HardFault_Handler( void );
extern void MemManage_Handler( void );
extern void BusFault_Handler( void );
extern void UsageFault_Handler( void );
extern void SVC_Handler( void );
extern void DebugMon_Handler( void );
extern void PendSV_Handler( void );
extern void SysTick_Handler( void );

extern void BrownOut_Handler (void);          
extern void ClkMon_Handler   (void);          
extern void PIN_Handler		 (void);
extern void RTC_FE_Handler	 (void);
extern void RTC_RE_Handler	 (void);
extern void I2C_Collision_Handler (void);
extern void I2C_Handler	 (void);
extern void UART_Handler (void);
extern void SPI_Handler	 (void);
extern void Default_IRQ_Handler (void);
extern void Timer0_Handler (void);
extern void Timer1_Handler (void);
extern void Timer2_Handler (void);
extern void Watchdog_Handler (void);


typedef void( *intfunc )( void );
typedef union { intfunc __fun; void * __ptr; } intvec_elem;

// The vector table is normally located at address 0.
// When debugging in RAM, it can be located in RAM, aligned to at least 2^6.
// If you need to define interrupt service routines,
// make a copy of this file and include it in your project.
// The name "__vector_table" has special meaning for C-SPY:
// it is where the SP start value is found, and the NVIC vector
// table register (VTOR) is initialized to this address if != 0.

#pragma location = ".intvec"
const intvec_elem __vector_table[] =
{
  { .__ptr = __sfe( "CSTACK" ) },
  __iar_program_start,
 
  NMI_Handler,
  HardFault_Handler,
  MemManage_Handler,
  BusFault_Handler,
  UsageFault_Handler,
  0,
  0,
  0,
  0,
  SVC_Handler,
  DebugMon_Handler,
  0,
  PendSV_Handler,
  SysTick_Handler,
  BrownOut_Handler,    		// IRQ 0 Brownout detector
  ClkMon_Handler,      		// IRQ 1 Clock monitor
  PIN_Handler,          	// IRQ 2 Pin change 
  RTC_FE_Handler,  			// IRQ 3 RTC falling edge interrupt	
  RTC_RE_Handler,  			// IRQ 4 RTC rising edge interrupt	
  I2C_Collision_Handler,  	// IRQ 5 I2C Collision
  I2C_Handler,  		    // IRQ 6 I2C
  UART_Handler,  		    // IRQ 7 UART
  SPI_Handler,  		    // IRQ 8 SPI
  Default_IRQ_Handler,  	// IRQ 9 
  Default_IRQ_Handler,  	// IRQ A
  Default_IRQ_Handler,  	// IRQ B
  Default_IRQ_Handler,  	// IRQ C
  Default_IRQ_Handler,  	// IRQ D
  Default_IRQ_Handler,  	// IRQ E
  Default_IRQ_Handler,  	// IRQ F
  Timer0_Handler,			// IRQ 10h Timer0	
  Timer1_Handler,			// IRQ 11h Timer1
  Timer2_Handler,			// IRQ 12h Timer2
  Watchdog_Handler			// IRQ 13h WDT
};

__weak void NMI_Handler( void ) { while (1) {} }
__weak void HardFault_Handler( void ) { while (1) {} }
__weak void MemManage_Handler( void ) { while (1) {} }
__weak void BusFault_Handler( void ) { while (1) {} }
__weak void UsageFault_Handler( void ) { while (1) {} }
__weak void SVC_Handler( void ) { while (1) {} }
__weak void DebugMon_Handler( void ) { while (1) {} }
__weak void PendSV_Handler( void ) { while (1) {} }

__weak extern void SysTick_Handler(void) {}
__weak extern void BrownOut_Handler(void) {}
__weak extern void ClkMon_Handler(void) {}      
__weak extern void PIN_Handler(void) {}
__weak extern void RTC_FE_Handler(void) {}
__weak extern void RTC_RE_Handler(void) {}
__weak extern void I2C_Collision_Handler(void) {}
__weak extern void I2C_Handler(void) {}
__weak extern void UART_Handler(void) {}
__weak extern void SPI_Handler(void) {}
__weak extern void Default_IRQ_Handler(void) {}
__weak extern void Timer0_Handler(void) {}
__weak extern void Timer1_Handler(void) {}
__weak extern void Timer2_Handler(void) {}
__weak extern void Watchdog_Handler(void) {}

void __cmain( void );
__weak void __iar_init_core( void );
__weak void __iar_init_vfp( void );

#pragma required=__vector_table
void __iar_program_start( void )
{
  __iar_init_core();
  __iar_init_vfp();
  __cmain();
}
