/**
 * @copyright 2015 Indie Semiconductor.
 *
 * This file is proprietary to Indie Semiconductor.
 * All rights reserved. Reproduction or distribution, in whole
 * or in part, is forbidden except by express written permission
 * of Indie Semiconductor.
 *
 * @file rtc_device.h
 */

#ifndef __RTC_DEVICE_H__
#define __RTC_DEVICE_H__

#include <stdint.h>
#include "hdf.h"

enum {
    RTC_MODE_NONE,
    RTC_MODE_RISING_EDGE,
    RTC_MODE_FALLING_EDGE,
};

typedef const struct RTC_Device_Type RTC_Device_t;
typedef void (*rtc_cb_func_t)(RTC_Device_t *dev);

/**
 * @brief A structure to represent RTC device state
 */
typedef struct {
    rtc_cb_func_t cb_func_r;
    rtc_cb_func_t cb_func_f;
    uint32_t    tick_r;
    uint32_t    tick_f;
} RTC_State_t;

/**
 * @brief A structure to represent RTC device
 */
struct RTC_Device_Type {
    IRQn_Type IRQR;
    IRQn_Type IRQF;
    void (*ClkDiv)(uint8_t div);
    RTC_State_t *State;
};

/**
 * @brief Request A RTC Device
 *
 * @return The pointer to the RTC device instance.
 */
RTC_Device_t *RTC_devRequest(void);

/**
 * @brief Initialize RTC Timer
 *
 * @param dev The pointer to RTC device,
 * @param mode The enumeration of rtc timer mode.
 * @param div The enumeration of rtc clock divider.
 * @param cb The pointer to the call back function for rising or falling edge.
 * @return 0 for success or error code upon a failure.
 */
int32_t RTC_devInit(RTC_Device_t *dev, uint8_t mode, uint8_t div, void *cb);

#endif /* __RTC_DEVICE_H__ */