/**
 * @copyright 2015 Indie Semiconductor.
 *
 * This file is proprietary to Indie Semiconductor.
 * All rights reserved. Reproduction or distribution, in whole
 * or in part, is forbidden except by express written permission
 * of Indie Semiconductor.
 *
 * @file wdt_device.h
 */

#ifndef __WDT_DEVICE_H__
#define __WDT_DEVICE_H__

#include <stdint.h>
#include "hdf.h"
#include "errno.h"

enum {
    WDT_MODE_DISABLE,
    WDT_MODE_INTERRUPT,
    WDT_MODE_RESET,
};    

typedef const struct WDT_Device_t WDT_Device_Type;
typedef void (*wdt_cb_func_t)(WDT_Device_Type *dev);

/**
 * @brief A structure to represent the state of a WDT device
 */
typedef struct {
    wdt_cb_func_t cb_func;
    uint32_t    tick;
} WDT_State_t;

/**
 * @brief A structure to represent WDT device
 */
typedef const struct  WDT_Device_t {
    void (*Enable)(void);
    void (*Disable)(void);
    void (*ResetEnable)(void);
    void (*ResetDisable)(void);
    void (*SetPrescaler)(uint8_t pres);
    uint8_t (*IsReset)(void);
    void (*Clear)(void);
    IRQn_Type IRQ;
    WDT_State_t *State;
} WDT_Device_t;

/**
 * @brief WDT Request Device
 *
 * @return The pointer to the WDT device instance.
 */
WDT_Device_t *WDT_devRequest(void);

/**
 * @brief Check if Watch Reset Occurred.
 *
 * @param dev The pointer to WDT device
 * @return 1 for reset occurred, 0 for no reset occurred or error code upon a failure.
 */
int32_t WDT_devIsReset(WDT_Device_t *dev);

/**
 * @brief Clear Watchdog Timer
 *
 * @param dev The pointer to WDT device
 * @return 0 for success or error code upon a failure.
 */
int32_t WDT_devClear(WDT_Device_t *dev);

/**
 * @brief Initialize Watchdog Timer
 *
 * @param dev The pointer to WDT device,
 * @param mode The enumeration of watchdog timer mode.
 * @param time The enumeration of time settings.
 * @param cb The pointer to the call back function if it is set to interrupt mode.
 * @return 0 for success or error code upon a failure.
 */
int32_t WDT_devInit(WDT_Device_t *dev, uint8_t mode, uint8_t time, void *cb);

#endif /* __WDT_DEVICE_H__ */

