/**
 * @copyright 2015 Indie Semiconductor.
 *
 * This file is proprietary to Indie Semiconductor.
 * All rights reserved. Reproduction or distribution, in whole
 * or in part, is forbidden except by express written permission
 * of Indie Semiconductor.
 *
 * @file clock_device.c
 */

#include "clock_device.h"
#include "hwcfg.h"
#include "errno.h"

#define CLOCK_INIT_RETRY_COUNT  15

int32_t Clock_devCrystalClockInit(void)
{
    uint32_t j = 0;
    uint8_t source;

    source = f_CLOCK_GetClockSource();
    if (source != E_CLOCK_SOURCE_XTCLOCK && source != E_CLOCK_SOURCE_RC12MHZ)
        f_CLOCK_SelectSource(E_CLOCK_SOURCE_RC12MHZ);
    source = f_CLOCK_GetClockSource();
    while (source != E_CLOCK_SOURCE_XTCLOCK) {
        if (!f_CLOCK_IsXTClockEnabled())
            f_CLOCK_EnableXTClock();
        f_CLOCK_SelectSource(E_CLOCK_SOURCE_XTCLOCK);
        if (j++ >= CLOCK_INIT_RETRY_COUNT)
            return -EFAULT;
        source = f_CLOCK_GetClockSource();
    }
    return 0;
}

void Clock_devRCClockInit(void)
{
    f_CLOCK_EnableRCClock();
    f_CLOCK_SelectSource(E_CLOCK_SOURCE_RC12MHZ);
}

void Clock_devRC10KClockInit(void)
{
    f_CLOCK_EnableRCClock();
    f_CLOCK_SelectSource(E_CLOCK_SOURCE_RC10KHZ);
}

void Clock_devRCCalibration()
{
    uint8_t trim = HWCFG_GetRCClockCalibValue();
    
    if (trim == 0xFF)
        return;
    f_CLOCK_RCTrim(trim);
}

void Clock_devEnableCrystalClock(void)
{
    f_CLOCK_EnableXTClock();
}

void Clock_devDisableCrystalClock(void)
{
    f_CLOCK_DisableXTClock();
}

void ClkMon_Handler ( void )
{
}
