/**
 * @copyright 2015 Indie Semiconductor.
 *
 * This file is proprietary to Indie Semiconductor.
 * All rights reserved. Reproduction or distribution, in whole
 * or in part, is forbidden except by express written permission
 * of Indie Semiconductor.
 *
 * @file led_device.c
 */

#include <stdint.h>
#include <string.h>
#include "hdf.h"
#include "errno.h"
#include "led_device.h"

#ifdef LED_SFRS
/**
 * @brief The instances of LED device
 */
static const LED_Device_t LED_Device = {
    .On = f_LED_On,
    .Off = f_LED_Off,
    .SetLightLevel = f_LED_SetLightLevel,
    .Name = "LED",
};
#endif /* LED_SFRS */

/**
 * @brief The table of LED device instances supported by the platform.
 */
const static LED_Device_t *LED_DeviceTable[] = {
#ifdef I2C_SFRS
    &LED_Device,
#endif
    NULL,
};

int32_t LED_devOn(LED_Device_t *dev, uint8_t pos)
{
    if (!dev || !dev->On)
        return -EFAULT;
    dev->On(pos);
    return 0;
}

int32_t LED_devOff(LED_Device_t *dev, uint8_t pos)
{
    if (!dev || !dev->Off)
        return -EFAULT;
    dev->Off(pos);
    return 0;
}

int32_t LED_devSetLightLevel(LED_Device_t *dev, uint8_t pos, uint8_t level)
{
    if (!dev || !dev->SetLightLevel)
        return -EFAULT;
    dev->SetLightLevel(pos, level);
    return 0;
}

LED_Device_t *LED_devRequest(const char *name)
{
    int8_t i;

    for (i = 0; i < sizeof(LED_DeviceTable)/sizeof(LED_DeviceTable[0]); i++) {
        if ((LED_DeviceTable[i] != NULL) &&
            (strncmp(name, LED_DeviceTable[i]->Name,
                    strlen(LED_DeviceTable[i]->Name)) == 0))
            return LED_DeviceTable[i];
    }
    return NULL;
}
