/**
 * @copyright 2015 Indie Semiconductor.
 *
 * This file is proprietary to Indie Semiconductor.
 * All rights reserved. Reproduction or distribution, in whole
 * or in part, is forbidden except by express written permission
 * of Indie Semiconductor.
 *
 * @file pwm_device.c
 */


#include <stdint.h>
#include <string.h>
#include "hdf.h"
#include "errno.h"
#include "pwm_device.h"

#if defined PWM1_SFRS
/**
 * @brief The instance of PMW1 device
 */
static PWM_Device_t PWM1_Device = {
    .Name = "PWM1",
   .SetPeriod = f_PWM1_SetPeriod,
   .SetWidth = f_PWM1_SetWidth,
   .SetPreScaler = f_PWM1_SetPreScaler,
   .InvertOn = f_PWM1_InvertOn,
   .Enable = f_PWM1_Enable,
   .InvertOff = f_PWM1_InvertOff,
   .Disable = f_PWM1_Disable,
};
#endif

#if defined PWM2_SFRS
/**
 * @brief The instance of PMW2 device
 */
static PWM_Device_t PWM2_Device = {
    .Name = "PWM2",
    .SetPeriod = f_PWM2_SetPeriod,
    .SetWidth = f_PWM2_SetWidth,
    .SetPreScaler = f_PWM2_SetPreScaler,
   .InvertOn = f_PWM2_InvertOn,
   .Enable = f_PWM2_Enable,
   .InvertOff = f_PWM2_InvertOff,
   .Disable = f_PWM2_Disable,
};
#endif

/**
 * @brief The table of PWM device instances supported by the platform.
 */
const static PWM_Device_t *PWM_DeviceTable[] = {
#ifdef PWM1_SFRS
    &PWM1_Device,
#endif
#ifdef PWM2_SFRS
    &PWM2_Device,
#endif
    NULL,
};

int32_t PWM_devSetPeriod(PWM_Device_t *dev, uint32_t period)
{
    if (!dev)
        return -EFAULT;
    dev->SetPeriod(period);
    return 0;
}
int32_t PWM_devSetWidth(PWM_Device_t *dev, uint32_t width)
{
    if (!dev)
        return -EFAULT;
    dev->SetWidth(width);
    return 0;
}
int32_t PWM_devSetClockDivider(PWM_Device_t *dev, uint8_t div)
{
    if (!dev)
        return -EFAULT;
    dev->SetPreScaler(div);
    return 0;
}

int32_t PWM_devInvertEnable(PWM_Device_t *dev)
{
    if (!dev)
        return -EFAULT;
    dev->InvertOn();
    return 0;
}

int32_t PWM_devInvertDisable(PWM_Device_t *dev)
{
    if (!dev)
        return -EFAULT;
    dev->InvertOff();
    return 0;
}

int32_t PWM_devEnable(PWM_Device_t *dev)
{
    if (!dev)
        return -EFAULT;
    dev->Enable();
    return 0;
}

int32_t PWM_devDisable(PWM_Device_t *dev)
{
    if (!dev)
        return -EFAULT;
    dev->Disable();
    return 0;
}

PWM_Device_t *PWM_devRequest(const char *name)
{
    int8_t i;

    for (i = 0; i < sizeof(PWM_DeviceTable)/sizeof(PWM_DeviceTable[0]); i++) {
        if ((PWM_DeviceTable[i] != NULL) &&
            (strncmp(name, PWM_DeviceTable[i]->Name,
                    strlen(PWM_DeviceTable[i]->Name)) == 0))
            return PWM_DeviceTable[i];
    }
    return NULL;
}
