/**
 * @copyright 2015 Indie Semiconductor.
 *
 * This file is proprietary to Indie Semiconductor.
 * All rights reserved. Reproduction or distribution, in whole
 * or in part, is forbidden except by express written permission
 * of Indie Semiconductor.
 *
 * @file rtc_device.c
 */

#include "rtc_device.h"
#include "errno.h"

/**
 * @brief The instance of RTC device
 */
#ifdef RTC_SFRS
extern RTC_State_t RTC_State;
const static RTC_Device_t RTC_Device =
{
    .IRQR = RTC_RE_IRQn,
    .IRQF = RTC_FE_IRQn,
    .State = &RTC_State,
    .ClkDiv = f_RTC_Div,
};    
#endif

RTC_Device_t *RTC_devRequest(void)
{
#ifdef RTC_SFRS
    return &RTC_Device;
#else
    return NULL,
#endif
}

RTC_State_t RTC_State =
{
    .cb_func_r = NULL, .cb_func_f = NULL, .tick_r = 0, .tick_f = 0,
};

void RTC_FE_Handler(void)
{
    if (RTC_State.cb_func_f != NULL)
        RTC_State.cb_func_f((RTC_Device_t *)&RTC_Device);
}

void RTC_RE_Handler(void)
{
    if (RTC_State.cb_func_r != NULL)
        RTC_State.cb_func_r((RTC_Device_t *)&RTC_Device);
}

int32_t RTC_devInit(RTC_Device_t *dev, uint8_t mode, uint8_t div, void *cb)
{
    if (!dev)
        return -EFAULT;

    switch(mode) {
    case RTC_MODE_RISING_EDGE:
        dev->State->cb_func_r = (rtc_cb_func_t)cb;
        dev->ClkDiv(div);
        NVIC_EnableIRQ(dev->IRQR);
        break;

    case RTC_MODE_FALLING_EDGE:
        dev->State->cb_func_f = (rtc_cb_func_t)cb;
        dev->ClkDiv(div);
        NVIC_EnableIRQ(dev->IRQF);
        break;

    case RTC_MODE_NONE:
    default:
        dev->State->cb_func_r = NULL;
        dev->State->cb_func_f = NULL;
        NVIC_DisableIRQ(dev->IRQR);
        NVIC_DisableIRQ(dev->IRQF);
        break;
    }
    return 0;
}