/**
 * @copyright 2015 Indie Semiconductor.
 *
 * This file is proprietary to Indie Semiconductor.
 * All rights reserved. Reproduction or distribution, in whole
 * or in part, is forbidden except by express written permission
 * of Indie Semiconductor.
 *
 * @file led_sfrs.h
 */

#ifndef __LED_SFRS_H__
#define __LED_SFRS_H__

/**
 * @brief A structure to represent Special Function Registers for LED.
 */
typedef struct {
    uint8_t CTRL;
    uint8_t RESERVED0[6];
    uint8_t MODE;
    uint8_t RESERVED[98210];
    uint8_t READEN;
    union {
        struct {
            uint8_t     NIBBLEL:4;
            uint8_t     NIBBLEH:4;
        };
        uint8_t  BYTE;
    } TRIM;
} LED_SFRS_t;

/**
 * @brief The starting address of LED SFRS.
 */
#define LED_SFRS ((__IO LED_SFRS_t *) (0x50000064))

/**
 * @brief Turn on LED
 *
 * @param pos The pin position on the LED port.
 */
void f_LED_On(uint8_t pos);

/**
 * @brief Turn off LED
 *
 * @brief @param pos The pin position on the LED port.
 */
void f_LED_Off(uint8_t pos);

/**
 * @brief Set LED light level
 *
 * @param pos The pin position on the LED port.
 * @param level The light level.
 */
void f_LED_SetLightLevel(uint8_t pos, uint8_t level);

#endif /* __LED_SFRS_H__ */