/**
 * @copyright 2015 Indie Semiconductor.
 *
 * This file is proprietary to Indie Semiconductor.
 * All rights reserved. Reproduction or distribution, in whole
 * or in part, is forbidden except by express written permission
 * of Indie Semiconductor.
 *
 * @file rtc_sfrs.h
 */

#ifndef __RTC_SFRS_H__
#define __RTC_SFRS_H__

/**
 * @brief A structure to represent Special Function Registers for RTC.
 */
typedef struct {
    union {
        struct {
            uint8_t     TRIM:2;
            uint8_t     DIV:2;
            uint8_t     RESERVED:4;
        };
        uint8_t BYTE;
    } RTCCTRL;
} RTC_SFRS_t;

/**
 * @brief The starting address of RTC SFRS.
 */
#define RTC_SFRS      ((__IO RTC_SFRS_t *)(ASIC_16B_BASE + 0x801A))

#define E_RTC_DIV_128           0
#define E_RTC_DIV_2048          1
#define E_RTC_DIV_32768         2
#define E_RTC_DIV_524288        3

#define E_RTC_TRIM_150K         0
#define E_RTC_TRIM_200K         1
#define E_RTC_TRIM_250K         2
#define E_RTC_TRIM_350K         3

/**
 * @brief Set RTC clock divider
 *
 * @param val The enumeration of RTC clock divider.
 */
static __INLINE void f_RTC_Div(uint8_t val)
{
    RTC_SFRS->RTCCTRL.DIV = val;
}

/**
 * @brief Set RTC trim value
 *
 * @param val The enumeration of RTC trim value.
 */
static __INLINE void f_RTC_Trim(uint8_t val)
{
    RTC_SFRS->RTCCTRL.TRIM = val;
}
#endif /* __RTC_SFRS_H__ */
