/**
 * @copyright 2015 Indie Semiconductor.
 *
 * This file is proprietary to Indie Semiconductor.
 * All rights reserved. Reproduction or distribution, in whole
 * or in part, is forbidden except by express written permission
 * of Indie Semiconductor.
 *
 * @file timer_sfrs.h
 */

#ifndef __TIMER_SFRS_H__
#define __TIMER_SFRS_H__

/**
 * @brief A structure to represent Special Function Registers for timers.
 */
typedef struct {
  __IO int32_t  COUNT;
  __IO uint8_t  CFG;
} TIMER_SFRS_t;

/**
 * @brief Starting address for Timer0 SFRS.
 */
#define TIMER0_SFRS                 ((TIMER_SFRS_t *) (TIMER_BASE + 0x00))

/**
 * @brief Starting address for Timer1 SFRS.
 */
#define TIMER1_SFRS                 ((TIMER_SFRS_t *) (TIMER_BASE + 0x08))

/**
 * @brief Starting address for Timer2 SFRS.
 */
#define TIMER2_SFRS                 ((TIMER_SFRS_t *) (TIMER_BASE + 0x10))


/**
 * @brief Start timer 0
 */
static __INLINE void f_Timer0_Start(void)
{
    TIMER0_SFRS->CFG = 1;
}

/**
 * @brief Stop timer 0
 */
static __INLINE void f_Timer0_Stop(void)
{
    TIMER0_SFRS->CFG = 0;
}

/**
 * @brief Load timing setting for timer 0
 */
static __INLINE void f_Timer0_LoadCounter(uint32_t cnt)
{
    TIMER0_SFRS->COUNT = cnt;
}

/**
 * @brief Start timer 1
 */
static __INLINE void f_Timer1_Start(void)
{
    TIMER1_SFRS->CFG = 1;
}

/**
 * @brief Stop timer 1
 */
static __INLINE void f_Timer1_Stop(void)
{
    TIMER1_SFRS->CFG = 0;
}

/**
 * @brief Load timing setting for timer 1
 */
static __INLINE void f_Timer1_LoadCounter(uint32_t cnt)
{
    TIMER1_SFRS->COUNT = cnt;
}

/**
 * @brief Start timer 2
 */
static __INLINE void f_Timer2_Start(void)
{
    TIMER2_SFRS->CFG = 1;
}

/**
 * @brief Stop timer 2
 */
static __INLINE void f_Timer2_Stop(void)
{
    TIMER2_SFRS->CFG = 0;
}

/**
 * @brief Load timing setting for timer 2
 */
static __INLINE void f_Timer2_LoadCounter(uint32_t cnt)
{
    TIMER2_SFRS->COUNT = cnt;
}
#endif /* __TIMER_SFRS_H__ */