/**
 * @copyright 2015 Indie Semiconductor.
 *
 * This file is proprietary to Indie Semiconductor.
 * All rights reserved. Reproduction or distribution, in whole
 * or in part, is forbidden except by express written permission
 * of Indie Semiconductor.
 *
 * @file wdt_sfrs.h
 */
 
#ifndef __WDT_SFRS_H__
#define __WDT_SFRS_H__

/**
 * @brief A structure to represent Special Function Registers for WDT.
 */
typedef struct {
    union {
        struct {
            uint8_t WDTEN:1;
            uint8_t RESETEN:1;
            uint8_t RSTFLAG:1;
            uint8_t WDTPRES:2;
            uint8_t Reserved:3;
        };
        uint8_t BYTE;    
    } WDTCTRL;
    uint8_t  Reserved[3];
    uint32_t WDTCLR;
} WDT_SFRS_t;

/**
 * @brief The starting address of WDT SFRS.
 */
#define WDT_SFRS              ((__IO WDT_SFRS_t *) (TIMER_BASE + 0x18))

#define WDT_PRES_2PWR13     0
#define WDT_PRES_2PWR19     1
#define WDT_PRES_2PWR22     2
#define WDT_PRES_2PWR32     3  

/**
 * @brief Enable watchdog timer.
 */
static __INLINE void f_WDT_Enable(void)
{
    WDT_SFRS->WDTCTRL.WDTEN = 1;
}

/**
 * @brief Disable watchdog timer.
 */
static __INLINE void f_WDT_Disable(void)
{
    WDT_SFRS->WDTCTRL.WDTEN = 0;
}

/**
 * @brief Enable watchdog timer reset.
 */
static __INLINE void f_WDT_ResetEnable(void)
{
    WDT_SFRS->WDTCTRL.RESETEN = 1;
}

/**
 * @brief Disable watchdog timer reset.
 */
static __INLINE void f_WDT_ResetDisable(void)
{
    WDT_SFRS->WDTCTRL.RESETEN = 0;
}

/**
 * @brief Select watchdog timer clock pre-scaler.
 *
 * @param val The setting of pre-scaler.
 */
static __INLINE void f_WDT_SetPrescaler(uint8_t val)
{
    WDT_SFRS->WDTCTRL.WDTPRES = val;
}

/**
 * @brief Clear watchdog timer.
 */
static __INLINE void f_WDT_Clear(void)
{
    WDT_SFRS->WDTCLR = 0x3C570001;
    WDT_SFRS->WDTCLR = 0x007F4AD6;   
} 

/**
 * @brief Check if watchdog timer reset occurred.
 *
 * @return The watchdog timer reset flag.
 */
static __INLINE uint8_t f_WDT_IsReset(void)
{
    return WDT_SFRS->WDTCTRL.RSTFLAG;
} 

#endif /* __WDT_SFRS_H__ */