/**
 * @copyright 2015 Indie Semiconductor.
 *
 * This file is proprietary to Indie Semiconductor.
 * All rights reserved. Reproduction or distribution, in whole
 * or in part, is forbidden except by express written permission
 * of Indie Semiconductor.
 *
 * @file main_uart.c
 */

#include "clock_device.h"
#include "gpio_device.h"
#include "pmu_device.h"
#include "systick_device.h"
#include "uart_device.h"

/************** Definitions ***************************************************/
#define SYSTICK_MS              (10)                            /* 10ms */
#define SYSTICK_INTERVAL        (E_HWCFG_SYSTEM_CLOCK/SYSTICK_MS)

#define TEST_LENGTH               8

/************** Local Variables ***********************************************/
static SysTick_Device_t *systick = NULL;
static char tx_data[] = "\n\n\r**** UART TEST ****\n\rEnter 8 characters here>";
static char rx_data[TEST_LENGTH];

/************** Global Variables **********************************************/
/************** Functions *****************************************************/

/************** MAIN ****************************************************/
void main_uart (void)
{
    int32_t ret;

    /* Initialize system clock */
    Clock_devRCCalibration();
    Clock_devRCClockInit();
    Clock_devEnableCrystalClock();

    /* Initialize power mode */
    PMU_devSetPowerModeLDO();

    /* Initialize SysTick driver */
    systick = SysTick_devRequest();
    if(!systick)
        return;
    SysTick_devInit(systick, SYSTICK_MODE_ENABLE_INTERRUPT, SYSTICK_INTERVAL, NULL);

    /* Config GPIO to UART mode */
    GPIO_ConfigUART(E_GPIO_PIN_MODE_ON, E_GPIO_PIN_NOSWAP, E_GPIO_PIN_NOINVERT);
    /* Request UART device */
    UART_Device_t *uart = UART_devRequest("UART");
    UART_Dev_LineInitData_t uart_config = {
        .DataSize = 8,
        .StopBits = 1,
        .ParityBit = UART_DEV_PARITY_BIT_ODD,
        .ParityEn = 0,
        .LoopBackEn = 0,
        .BreakEn = 0,
        .StickyParityEn = 0,
    };
    /* Initialize UART device */
    ret = UART_devInit(uart, UART_DEV_BAUDRATE_9600, &uart_config);
    if (ret)
        return;

    while (1) {
        if (UART_devCheckError(uart))
            UART_devResetDevice(uart);
        /* Send data through UART device */
        UART_devSendByte(uart, (uint8_t *)&tx_data, sizeof(tx_data)/sizeof(tx_data[0]));
        /* Wait for data arrived */
        while (UART_devDataReceived(uart) < TEST_LENGTH);
        /* Read data from driver */
        UART_devReceiveByte(uart, (uint8_t *)&rx_data, TEST_LENGTH);
    } /* while (1) */
} /* main() */

/***************************** End of File ************************************/